/*
 * Copyright 2013 Malcolm Lett
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sourceforge.tedhi;

/**
 * Controls to what extent a date is defined.
 * A date that is defined to a level of {@link #MONTH} has a year
 * and month, but it's day and all finer grained fields have been defaulted.
 * @author Malcolm Lett
 */
public enum DefinedLevel {
	YEAR,
	MONTH,
	DAY,
	;
	
	public boolean isLessSignificantThan(DefinedLevel other) {
		return this.ordinal() > other.ordinal();
	}

	public boolean isLessSignificantThanOrEqualTo(DefinedLevel other) {
		return this.ordinal() >= other.ordinal();
	}

	public boolean isMoreSignificantThan(DefinedLevel other) {
		return this.ordinal() < other.ordinal();
	}

	public boolean isMoreSignificantThanOrEqualTo(DefinedLevel other) {
		return this.ordinal() <= other.ordinal();
	}

	public static DefinedLevel lessSignificantOf(DefinedLevel one, DefinedLevel two) {
		return one.isLessSignificantThan(two) ? one : two;
	}

	public static DefinedLevel moreSignificantOf(DefinedLevel one, DefinedLevel two) {
		return one.isMoreSignificantThan(two) ? one : two;
	}
}
